@@ -354,4 +354,32 @@ class pfdo(object):
         else:
             self.dp.qprint('Returning from pfdo base class run...', level = 1)
 
-        return d_ret
\ No newline at end of file
+        return d_ret
+
+class object_factoryCreate:
+    """
+    A class that examines input file string for extension information and
+    returns the relevant convert object.
+    """
+
+    def __init__(self, args):
+        """
+        Parse relevant CLI args.
+        """
+
+        self.C_convert = pfdo(
+            inputFile            = args.inputFile,
+            inputDir             = args.inputDir,
+            outputDir            = args.outputDir,
+            filterExpression     = args.filter,
+            printElapsedTime     = args.printElapsedTime,
+            threads              = args.threads,
+            outputLeafDir        = args.outputLeafDir,
+            test                 = args.test,
+            man                  = args.man,
+            synopsis             = args.synopsis,
+            json                 = args.json,
+            followLinks          = args.followLinks,
+            verbosity            = args.verbosity,
+            version              = args.version
+        )
\ No newline at end of file
